Coverage report

File | function |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src / typed_event.py | Event.__init__ |  | 19 | 0 | 0 |  | 100%
src / typed_event.py | Event.__get__ |  | 10 | 0 | 0 |  | 100%
src / typed_event.py | Event.__call__ |  | 26 | 0 | 0 |  | 100%
src / typed_event.py | Event.__iadd__ |  | 2 | 0 | 0 |  | 100%
src / typed_event.py | Event.__isub__ |  | 2 | 0 | 0 |  | 100%
src / typed_event.py | Event.__str__ |  | 3 | 0 | 0 |  | 100%
src / typed_event.py | event |  | 0 | 0 | 1 |  | 100%
src / typed_event.py | event |  | 0 | 0 | 1 |  | 100%
src / typed_event.py | event |  | 4 | 0 | 1 |  | 100%
src / typed_event.py | event.wrap |  | 1 | 0 | 0 |  | 100%
src / typed_event.py | (no function) |  | 21 | 0 | 17 |  | 100%
Total |  |  | 88 | 0 | 20 |  | 100%

No items found using the specified filter.